/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.taxonomy.apio.internal.architect.form;

import com.liferay.apio.architect.form.Form;

import java.util.Collections;
import java.util.Locale;
import java.util.Map;

/**
 * Instances of this class represent the values extracted from a taxonomy form.
 *
 * @author Eduardo Perez
 * @author Javier Gamarra
 * @review
 */
public class TaxonomyForm {

	/**
	 * Builds a {@code Form} that generates {@code TaxonomyForm} depending on
	 * the HTTP body.
	 *
	 * @param  builder the {@code Form} builder
	 * @return a taxonomy form
	 * @review
	 */
	public static Form<TaxonomyForm> buildForm(
		Form.Builder<TaxonomyForm> builder) {

		return builder.title(
			__ -> "Taxonomy form"
		).description(
			__ -> "This form can be used to create or update a taxonomy"
		).constructor(
			TaxonomyForm::new
		).addOptionalString(
			"description", TaxonomyForm::_setDescription
		).addRequiredString(
			"name", TaxonomyForm::_setName
		).build();
	}

	/**
	 * Returns the taxonomy's description map.
	 *
	 * @return the taxonomy's description map
	 * @review
	 */
	public Map<Locale, String> getDescriptions(Locale locale) {
		return Collections.singletonMap(locale, _description);
	}

	/**
	 * Returns the taxonomy's description map.
	 *
	 * @return the taxonomy's description map
	 * @review
	 */
	public Map<Locale, String> getTitles(Locale locale) {
		return Collections.singletonMap(locale, _name);
	}

	private void _setDescription(String description) {
		_description = description;
	}

	private void _setName(String name) {
		_name = name;
	}

	private String _description;
	private String _name;

}